========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - |
        |
    * - package
      - | |version| |downloads| |wheel| |supported-versions| |supported-implementations|
        | |commits-since|

.. |docs| image:: https://readthedocs.org/projects/deployv-addon-gitlab-tools/badge/?style=flat
    :target: https://readthedocs.org/projects/deployv-addon-gitlab-tools
    :alt: Documentation Status

.. |version| image:: https://img.shields.io/pypi/v/deployv-addon-gitlab-tools.svg
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/deployv-addon-gitlab-tools

.. |commits-since| image:: https://img.shields.io/github/commits-since/Vauxoo/deployv-addon-gitlab-tools/v0.2.38.svg
    :alt: Commits since latest release
    :target: https://github.com/Vauxoo/deployv-addon-gitlab-tools/compare/v0.2.38...master

.. |downloads| image:: https://img.shields.io/pypi/dm/deployv-addon-gitlab-tools.svg
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/deployv-addon-gitlab-tools

.. |wheel| image:: https://img.shields.io/pypi/wheel/deployv-addon-gitlab-tools.svg
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/deployv-addon-gitlab-tools

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/deployv-addon-gitlab-tools.svg
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/deployv-addon-gitlab-tools

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/deployv-addon-gitlab-tools.svg
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/deployv-addon-gitlab-tools


.. end-badges

Deployv addon: Gitlab tools. Generated by cookiecutter and cookiecutter-deploy-addon.

A small set of tools to automate repetitive tasks for testing gitlab repositories.

It is important to say that this is not by any mean a replacement for the MQT tools, these are tools that we need in order to make gitlab-ci work properly with the MQT tools.

* Free software: BSD license

Installation
============

::

    pip install deployv-addon-gitlab-tools

Documentation
=============

https://deployv-addon-gitlab-tools.readthedocs.io/

Development
===========

To run the all tests run::

    tox

Note, to combine the coverage data from all the tox environments run:

.. list-table::
    :widths: 10 90
    :stub-columns: 1

    - - Windows
      - ::

            set PYTEST_ADDOPTS=--cov-append
            tox

    - - Other
      - ::

            PYTEST_ADDOPTS=--cov-append tox
